@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::WSS::Sign::RSA;
 use vars '$VERSION';
-$VERSION = '1.07';
+$VERSION = '1.08';
 
 use base 'XML::Compile::WSS::Sign';
 
@@ -43,8 +43,8 @@ sub privateKey(;$)
     if(blessed $priv && $priv->isa('Crypt::OpenSSL::RSA'))
     {   ($key, $rsa) = ($priv->get_private_key_string, $priv);
     }
-    elsif(ref $priv)
-    {   error __x"unrecognized private key object `{object}'", object => $priv;
+    elsif(ref $priv =~ m/Crypt/)
+    {   error __x"unsupported private key object `{object}'", object => $priv;
     }
     elsif(index($priv, "\n") >= 0)
     {   ($key, $rsa) = ($priv, Crypt::OpenSSL::RSA->new_private_key($priv));
